@@ -1,7 +1,7 @@
 from decimal import Decimal
 
 from django.core.validators import validate_comma_separated_integer_list
-from django.utils.translation import ugettext_lazy as _, pgettext_lazy
+from django.utils.translation import gettext_lazy as _, pgettext_lazy
 from django_countries.serializer_fields import CountryField
 from internationalflavor.iban import IBANValidator
 from internationalflavor.vat_number import VATNumberValidator
@@ -726,6 +726,13 @@ class ContactSerializer(serializers.Serializer):
     """
     opt_in_evaluations = serializers.BooleanField(required=True)
 
+    """
+    will this contact receive information about new products, services and special offers?
+
+    """
+
+    opt_in_marketing = serializers.BooleanField(required=False)
+
     """
     is this contact allowed to access the customer area and product statistics?
 
@@ -1763,7 +1770,7 @@ class OrderLineSeoSerializer(serializers.Serializer):
 
     """
     regions = serializers.ListField(
-        child=serializers.CharField(max_length=100, required=True), required=True, allow_empty=False)
+        child=serializers.CharField(max_length=100, required=True), required=False)
 
     """
     main focus of the seo optimization, which of the customers products/services is the most important?
@@ -1793,7 +1800,7 @@ class OrderLineSeoSerializer(serializers.Serializer):
     redmine ticket id of the original seo offer inquiry
 
     """
-    ticket_id = serializers.CharField(max_length=20, required=True)
+    ticket_id = serializers.CharField(max_length=20, required=False)
 
 
 class OrderLineLandingpageSerializer(serializers.Serializer):
